@@ -28,6 +28,7 @@ use std::{
 /// Trait implementing all helper functions for Curl-driven checks
 pub trait GenericChecker {
     /// Executes domain checks, returns Stories
+    #[instrument(skip(checks))]
     fn check_domains(checks: &[Check]) -> Stories {
         checks
             .into_par_iter()
@@ -64,6 +65,7 @@ pub trait GenericChecker {
 
 
     /// Executes page checks, returns Stories
+    #[instrument(skip(checks))]
     fn check_pages(checks: &[Check]) -> Stories {
         checks
             .iter()
@@ -77,9 +79,10 @@ pub trait GenericChecker {
                     multi.pipelining(false, true).unwrap_or_default(); // disable http1.1, enable http2-multiplex
 
                     // collect tuple of page-checks and Curl handler:
+                    #[allow(clippy::needless_collect)] // Clippy BUG: not needless!
                     let process_handlers: Vec<_> = all_pages
                         .iter()
-                        .map(|check| (check, Self::load_handler_for(&check, &multi)))
+                        .map(|check| (check, Self::load_handler_for(check, &multi)))
                         .collect();
 
                     // perform all checks at once:
@@ -93,12 +96,7 @@ pub trait GenericChecker {
                     process_handlers
                         .into_iter()
                         .flat_map(|(page, handler)| {
-                            Self::process_page_handler(
-                                &page,
-                                handler,
-                                &multi,
-                                notifier.clone(),
-                            )
+                            Self::process_page_handler(page, handler, &multi, notifier.clone())
                         })
                         .collect::<Stories>()
                 })
@@ -108,12 +106,13 @@ pub trait GenericChecker {
 
 
     /// Check SSL certificate expiration using OpenSSL function
+    #[instrument]
     fn check_ssl_expire(
         domain_name: &str,
         domain_expectation: DomainExpectation,
         notifier: Option<String>,
     ) -> Story {
-        SslExpiration::from_domain_name_with_timeout(&domain_name, CHECK_TIMEOUT)
+        SslExpiration::from_domain_name_with_timeout(domain_name, CHECK_TIMEOUT)
             .map(|ssl_validator| {
                 match domain_expectation {
                     DomainExpectation::ValidExpiryPeriod(expected_days)
@@ -150,6 +149,7 @@ pub trait GenericChecker {
     }
 
     /// Build a Story from a Length PageExpectation
+    #[instrument]
     fn handle_page_length_expectation(
         url: &str,
         raw_page_content: &str,
@@ -195,6 +195,7 @@ pub trait GenericChecker {
 
 
     /// Find and extract code validation from validations
+    #[instrument]
     fn find_code_validation(page_expectations: &[PageExpectation]) -> &PageExpectation {
         page_expectations
             .par_iter()
@@ -206,6 +207,7 @@ pub trait GenericChecker {
 
 
     /// Find and extract content validations
+    #[instrument]
     fn find_content_validations(page_expectations: &[PageExpectation]) -> PageExpectations {
         page_expectations
             .par_iter()
@@ -216,6 +218,7 @@ pub trait GenericChecker {
 
 
     /// Find and extract content length validation from validations
+    #[instrument]
     fn find_content_length_validation(
         page_expectations: &[PageExpectation],
     ) -> &PageExpectation {
@@ -227,6 +230,7 @@ pub trait GenericChecker {
 
 
     /// Find and extract address validation from validations
+    #[instrument]
     fn find_address_validation(page_expectations: &[PageExpectation]) -> &PageExpectation {
         page_expectations
             .par_iter()
@@ -236,6 +240,7 @@ pub trait GenericChecker {
 
 
     /// Converts CurlError to Error
+    #[instrument]
     fn produce_curl_response_error(err: CurlError) -> Error {
         let mut reason = "";
         if err.is_failed_init() {
@@ -328,6 +333,7 @@ pub trait GenericChecker {
 
 
     /// Build a Story from a Length PageExpectation
+    #[instrument]
     fn handle_page_content_expectations(
         url: &str,
         raw_page_content: &str,
@@ -377,6 +383,7 @@ pub trait GenericChecker {
 
 
     /// Build a Story from a Address PageExpectation
+    #[instrument]
     fn handle_page_address_expectation(
         url: &str,
         address: &str,
@@ -423,6 +430,7 @@ pub trait GenericChecker {
 
 
     /// Build a Story from a HttpCode PageExpectation
+    #[instrument]
     fn handle_page_httpcode_expectation(
         url: &str,
         connect_oserror: Option<Error>,
@@ -493,6 +501,7 @@ pub trait GenericChecker {
 
 
     /// Process Curl page requests using given handler
+    #[instrument]
     fn process_page_handler(
         page_check: &Page,
         handler: CurlHandler,
@@ -500,28 +509,21 @@ pub trait GenericChecker {
         notifier: Option<String>,
     ) -> Stories {
         let page_expectations = page_check.clone().expects;
-        trace!(
-            "process_page_handler::page_expectations: {:?}",
-            page_expectations
-        );
+        let url = &page_check.url;
 
         // take control over curl handler, perform validations, produce stories…
         let a_handler = match handler {
             Ok(handle) => {
                 if handle.get_ref().0.is_empty() {
-                    let fail = format!("Site is down: {}", page_check.url);
-                    error!("{}", fail);
+                    let fail = format!("Site is down: {url}");
+                    error!(target: "checks", "{fail}");
                     return vec![Story::error(Unexpected::HandlerFailed(fail), notifier)];
                 } else {
                     handle
                 }
             }
             Err(err) => {
-                error!(
-                    "Couldn't connect to: {}. Error details: {:?}",
-                    page_check.url,
-                    err.to_string()
-                );
+                error!("Couldn't connect to: {url}. Error details: {err}",);
                 return vec![Story::error(
                     Unexpected::HandlerFailed(err.description().to_string()),
                     notifier,
@@ -531,27 +533,10 @@ pub trait GenericChecker {
 
         let handle = a_handler.get_ref().0.to_owned();
         let raw_page_content = String::from_utf8(handle).unwrap_or_default();
-        trace!(
-            "process_page_handler::raw_page_content: {:?}",
-            raw_page_content
-        );
         let expected_code = Self::find_code_validation(&page_expectations);
-        trace!("process_page_handler::expected_code: {:?}", expected_code);
         let expected_contents = Self::find_content_validations(&page_expectations);
-        trace!(
-            "process_page_handler::expected_contents: {:?}",
-            expected_contents
-        );
         let expected_content_length = Self::find_content_length_validation(&page_expectations);
-        trace!(
-            "process_page_handler::expected_content_length: {:?}",
-            expected_content_length
-        );
         let expected_final_address = Self::find_address_validation(&page_expectations);
-        trace!(
-            "process_page_handler::expected_final_address: {:?}",
-            expected_final_address
-        );
 
         // Gather Story from expectations
         let content_stories = Self::handle_page_content_expectations(
@@ -560,17 +545,12 @@ pub trait GenericChecker {
             &expected_contents,
             notifier.clone(),
         );
-        trace!("process_page_handler::content_story: {:?}", content_stories);
         let content_length_story = vec![Self::handle_page_length_expectation(
             &page_check.url,
             &raw_page_content,
             expected_content_length,
             notifier.clone(),
         )];
-        trace!(
-            "process_page_handler::content_length_story: {:?}",
-            content_length_story
-        );
 
         let mut result_handler = match multi.remove2(a_handler) {
             Ok(res_handler) => res_handler,
@@ -589,21 +569,15 @@ pub trait GenericChecker {
         let result_final_address = result_handler.effective_url().unwrap_or_default();
         let result_final_address_story = vec![Self::handle_page_address_expectation(
             &page_check.url,
-            &result_final_address.unwrap_or_default(),
+            result_final_address.unwrap_or_default(),
             expected_final_address,
             notifier.clone(),
         )];
-        trace!(
-            "process_page_handler::result_final_address_story: {:?}",
-            result_final_address_story
-        );
         let connect_oserror = match result_handler.os_errno() {
             Ok(0) => None,
             Ok(err_code) => Some(Error::from_raw_os_error(err_code)),
             Err(error) => Some(Error::from_raw_os_error(error.code() as i32)),
         };
-        trace!("Connect OS error: {:?}", connect_oserror);
-
         let result_handler_story = vec![Self::handle_page_httpcode_expectation(
             &page_check.url,
             connect_oserror,
@@ -613,9 +587,9 @@ pub trait GenericChecker {
             expected_code,
             notifier,
         )];
+
         trace!(
-            "process_page_handler::handle_page_httpcode_expectation: {:?}",
-            result_handler_story
+            "process_page_handler::page_expectations: {page_expectations:?}. process_page_handler::expected_code: {expected_code:?}. process_page_handler::expected_contents: {expected_contents:?}. process_page_handler::expected_content_length: {expected_content_length:?}. process_page_handler::expected_final_address: {expected_final_address:?}. process_page_handler::content_story: {content_stories:?}. process_page_handler::content_length_story: {content_length_story:?}. process_page_handler::result_final_address_story: {result_final_address_story:?}. process_page_handler::handle_page_httpcode_expectation: {result_handler_story:?}. process_page_handler::raw_page_content: {raw_page_content:?}."
         );
 
         // Collect the history results
@@ -630,6 +604,7 @@ pub trait GenericChecker {
 
 
     /// Build headers List for Curl
+    #[instrument]
     fn list_of_headers(headers: Option<Vec<String>>) -> List {
         // Build List of HTTP headers
         // ex. header:
@@ -644,6 +619,7 @@ pub trait GenericChecker {
 
 
     /// Build cookies list for Curl
+    #[instrument]
     fn list_of_cookies(headers: Option<Vec<String>>) -> String {
         let mut cookies = vec![];
         for cookie in headers.unwrap_or_default() {
@@ -655,11 +631,12 @@ pub trait GenericChecker {
 
 
     /// Load page check handler
+    #[instrument]
     fn load_handler_for(page_check: &Page, multi: &Multi) -> CurlHandler {
         // Initialize Curl, set URL
         let mut curl = Easy2::new(Collector(Vec::new()));
         curl.url(&page_check.url).unwrap_or_default();
-        trace!("Curl URL: {}", &page_check.url);
+        trace!("Curl URL: {}", page_check.url);
 
         // Load Curl request options from check:
         let curl_options = page_check.clone().options.unwrap_or_default();
